diff scripts/java/javafields.m @ 15772:0f1a143e5002

Overhaul scripts/java directory to conform to Octave core. Update docstrings. Use Octave coding conventions. Use default arguments where possible. Match variable names in docstring to variable names in function. HG: Enter commit message. Lines beginning with 'HG:' are removed. HG: Leave message empty to abort commit. HG: -- HG: user: Rik <rik@octave.org> HG: branch 'default' * errordlg.m, helpdlg.m, inputdlg.m, javaArray.m, javaaddpath.m, javaclasspath.m, javafields.m, javamem.m, javamethods.m, javarmpath.m, listdlg.m, msgbox.m, questdlg.m, warndlg.m: Overhaul functions. Update docstrings. Use Octave coding conventions. Use default arguments where possible. Match variable names in docstring to variable names in function.
author Rik <rik@octave.org>
date Wed, 12 Dec 2012 13:48:47 -0800
parents 54e8c2527a9e
children
line wrap: on
line diff
--- a/scripts/java/javafields.m	Wed Dec 12 13:33:37 2012 -0800
+++ b/scripts/java/javafields.m	Wed Dec 12 13:48:47 2012 -0800
@@ -17,30 +17,31 @@
 ## <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
 ## @deftypefn {Function file} {@var{p} =} javafields (@var{class})
 ## Return the fields of a Java object in the form of a cell 
 ## array of strings.  If no output is requested, print the result
-## printed on the standard output.
-## @seealso{javamethods}
+## to the standard output.
+## @seealso{javamethods, javaObject}
 ## @end deftypefn
 
-function retval = javafields (classname)
+function fld_names = javafields (javaobj)
   
   if (nargin != 1)
     print_usage ();
-  else
-    c_methods = java_invoke ("org.octave.ClassHelper", "getFields", classname);
-    method_list = strsplit (c_methods, ';');
+  endif
+  
+  c_methods = java_invoke ("org.octave.ClassHelper", "getFields", javaobj);
+  method_list = strsplit (c_methods, ';');
 
-    switch (nargout)
-      case 0
-        if (! isempty (method_list))
-          disp (method_list);
-        endif
-
-      case 1
-        retval = cellstr (method_list);
-   endswitch
- endif
+  if (nargout == 0)
+    if (! isempty (method_list))
+      disp (method_list);
+    endif
+  else
+    fld_names = cellstr (method_list);
+  endif
 
 endfunction
+
@@ -17,30 +17,31 @@
 
 ## -*- texinfo -*-
-## @deftypefn {Function file} {@var{p} =} javafields (@var{class})
-## Return the fields of a Java object in the form of a cell 
+## @deftypefn  {Function File} {} javafields (@var{javaobj})
+## @deftypefnx {Function File} {} javafields ("@var{classname}")
+## @deftypefnx {Function File} {@var{fld_names} =} javafields (@dots{})
+## Return the fields of a Java object or Java class in the form of a cell 
 ## array of strings.  If no output is requested, print the result